@@ -67,14 +67,15 @@ setMethod("initialize", "AbscontDistribution",
                    gaps = NULL, param = NULL, img = new("Reals"),
                    .withSim = FALSE, .withArith = FALSE,
                    .lowerExact = FALSE, .logExact = FALSE,
-                   low1 = NULL, up1 = NULL, low = -Inf, up =Inf
+                   low1 = NULL, up1 = NULL, low = -Inf, up =Inf,
+                   Symmetry = NoSymmetry()
                    ) {
             ## don't use this if the call is new("AbscontDistribution")
             LL <- length(sys.calls())
-            if(sys.calls()[[LL-3]] == "new(\"AbscontDistribution\")")
-               {return(.Object)}
             if(sys.calls()[[LL-3]] == "new(toDef)")
                {return(.Object)}
+            if(sys.calls()[[LL-3]] == "new(\"AbscontDistribution\")")
+               {return(.Object)}
             
             if(is.null(r))
                warning("you have to specify slot r at least")
@@ -127,6 +128,7 @@ setMethod("initialize", "AbscontDistribution",
             .Object@.withArith <- .withArith
             .Object@.logExact <- .logExact
             .Object@.lowerExact <- .lowerExact
+            .Object@Symmetry <- Symmetry
             .Object })
 
 ## class AffLinAbscontDistribution
@@ -134,7 +136,8 @@ setMethod("initialize", "AffLinAbscontDistribution",
           function(.Object, r = NULL, d = NULL, p = NULL, q = NULL, gaps = NULL,
                    a = 1, b = 0, X0 = Norm(), param = NULL, img = new("Reals"),
                    .withSim = FALSE, .withArith = FALSE,
-                   .lowerExact = FALSE, .logExact = FALSE) {
+                   .lowerExact = FALSE, .logExact = FALSE,
+                   Symmetry = NoSymmetry()) {
   X <- new("AbscontDistribution", r = r, d = d, p = p, q = q, gaps = gaps, 
            param = param, img = img, .withSim = .withSim, 
            .withArith = .withArith)
@@ -150,6 +153,7 @@ setMethod("initialize", "AffLinAbscontDistribution",
   .Object@r <- X@r
   .Object@.withSim <- .withSim
   .Object@.withArith <- .withArith
+  .Object@Symmetry <- Symmetry
   .Object
 })
 
@@ -158,7 +162,8 @@ setMethod("initialize", "DiscreteDistribution",
           function(.Object, r = NULL, d = NULL, p = NULL, q = NULL, 
                     support = NULL, param = NULL, img = new("Reals"), 
                     .withSim = FALSE, .withArith = FALSE,
-                   .lowerExact = FALSE, .logExact = FALSE) {
+                   .lowerExact = FALSE, .logExact = FALSE,
+                   Symmetry = NoSymmetry()) {
 
             ## don't use this if the call is new("DiscreteDistribution")
             LL <- length(sys.calls())
@@ -218,6 +223,7 @@ setMethod("initialize", "DiscreteDistribution",
             .Object@.withArith <- .withArith
             .Object@.lowerExact <- .lowerExact
             .Object@.logExact <- .logExact
+            .Object@Symmetry <- Symmetry
             .Object
           })
 
@@ -226,7 +232,8 @@ setMethod("initialize", "AffLinDiscreteDistribution",
           function(.Object, r = NULL, d = NULL, p = NULL, q = NULL, 
                    support = NULL, a = 1, b = 0, X0 = Binom(), param = NULL, 
                    img = new("Reals"), .withSim = FALSE, .withArith = FALSE,
-                   .lowerExact = FALSE, .logExact = FALSE) {
+                   .lowerExact = FALSE, .logExact = FALSE,
+                   Symmetry = NoSymmetry()) {
    ## don't use this if the call is new("DiscreteDistribution")
    LL <- length(sys.calls())
    if(sys.calls()[[LL-3]] == "new(\"AffLinDiscreteDistribution\")")
@@ -248,6 +255,7 @@ setMethod("initialize", "AffLinDiscreteDistribution",
   .Object@.withArith <- .withArith
   .Object@.lowerExact <- .lowerExact
   .Object@.logExact <- .logExact
+  .Object@Symmetry <- Symmetry
   .Object
 })
 
@@ -256,7 +264,8 @@ setMethod("initialize", "LatticeDistribution",
           function(.Object, r = NULL, d = NULL, p = NULL, q = NULL, 
                     support = NULL, lattice = NULL, param = NULL, 
                     img = new("Reals"), .withSim = FALSE, .withArith = FALSE,
-                   .lowerExact = FALSE, .logExact = FALSE) {
+                   .lowerExact = FALSE, .logExact = FALSE,
+                   Symmetry = NoSymmetry()) {
 
 
              LL <- length(sys.calls())
@@ -290,6 +299,7 @@ setMethod("initialize", "LatticeDistribution",
             .Object@.withArith <- .withArith
             .Object@.lowerExact <- .lowerExact
             .Object@.logExact <- .logExact
+            .Object@Symmetry <- Symmetry
             .Object
           })
 
@@ -298,7 +308,8 @@ setMethod("initialize", "AffLinLatticeDistribution",
           function(.Object, r = NULL, d = NULL, p = NULL, q = NULL, 
                    support = NULL, lattice = NULL, a = 1, b = 0, X0 = Binom(), 
                    param = NULL, img = new("Reals"), .withSim = FALSE, 
-                   .withArith = FALSE, .lowerExact = FALSE, .logExact = FALSE) {
+                   .withArith = FALSE, .lowerExact = FALSE, .logExact = FALSE,
+                   Symmetry = NoSymmetry()) {
 
    LL <- length(sys.calls())
    if(sys.calls()[[LL-3]] == "new(\"AffLinLatticeDistribution\")")
@@ -323,6 +334,7 @@ setMethod("initialize", "AffLinLatticeDistribution",
   .Object@.withArith <- .withArith
   .Object@.lowerExact <- .lowerExact
   .Object@.logExact <- .logExact
+  .Object@Symmetry <- Symmetry
   .Object
 })
 
@@ -586,6 +598,7 @@ setMethod("initialize", "Unif",
                              list(MinSub = Min, MaxSub = Max)
                                           )                    
             .Object@.withArith <- .withArith
+            .Object@Symmetry <- SphericalSymmetry(Min+Max/2)
             .Object
           })
 
@@ -618,6 +631,7 @@ setMethod("initialize", "Norm",
                              list(meanSub = mean, sdSub = sd)
                                           )
             .Object@.withArith <- .withArith
+            .Object@Symmetry <- SphericalSymmetry(mean)
             .Object
           })
 
@@ -690,6 +704,7 @@ setMethod("initialize", "Cauchy",
                                           )
             .Object@.withSim   <- FALSE
             .Object@.withArith <- FALSE
+            .Object@Symmetry <- SphericalSymmetry(location)
             .Object
           })
 
@@ -778,6 +793,7 @@ setMethod("initialize", "Td",
                                          list(dfSub = df, ncpSub = ncp)
                                           )
             .Object@.withArith <- FALSE
+            .Object@Symmetry <- SphericalSymmetry(0)
             .Object
           })
 
@@ -894,6 +910,7 @@ setMethod("initialize", "DExp",
                                           )
             .Object@.withSim   <- FALSE
             .Object@.withArith <- .withArith
+            .Object@Symmetry <- SphericalSymmetry(0)
             .Object
           })
 
@@ -1070,5 +1087,6 @@ setMethod("initialize", "Arcsine",
                               return(q)}                      
             .Object@.withSim   <- FALSE
             .Object@.withArith <- .withArith
+            .Object@Symmetry <- SphericalSymmetry(0)
             .Object
           })
